==> senior_design_system-0.26.2.tar.gz: lib/components/senior_modal/senior_modal_widget.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_modal_style.dart';
import '../../themes/senior_theme_provider.dart';
import '../../components/senior_button/senior_button.dart';
import '../../themes/senior_theme.dart';

class SeniorModal extends StatelessWidget {
  /// Displays a modal according to SDS definitions.
  ///
  /// The [content], [ghostButton] and [title] parameters are required.
  const SeniorModal({
    Key? key,
    this.actionButton,
    required this.content,
    required this.ghostButton,
    this.style,
    required this.title,
  }) : super(key: key);

  /// Modal action button. It is recommended to use a button that is not of type [SeniorButtonType.ghost].
  final SeniorButton? actionButton;

  /// The information content that will be displayed in the modal.
  final String content;

  /// Modal action button. It is recommended to use a button of type [SeniorButtonType.ghost].
  final SeniorButton ghostButton;

  /// The component's style definitions.
  ///
  /// Allows you to configure:
  /// [SeniorModalStyle.backgroundColor] the background color of the modal.
  final SeniorModalStyle? style;

  /// The modal title.
  final String title;

  @override
  Widget build(BuildContext context) {
    final SeniorTheme? theme = SeniorThemeProvider.getTheme(context);
    final SeniorTheme defaultTheme =
        SeniorThemeProvider.getDefaultTheme(context);

    return AlertDialog(
      backgroundColor: style?.backgroundColor ??
          theme?.modalTheme?.style?.backgroundColor ??
          defaultTheme.modalTheme?.style?.backgroundColor ??
          SeniorColors.pureWhite,
      title: Text(
        title,
        style: SeniorTypography.h3(
          color: style?.titleColor ??
              theme?.modalTheme?.style?.titleColor ??
              defaultTheme.modalTheme?.style?.titleColor ??
              SeniorColors.neutralColor800,
        ),
      ),
      titlePadding: const EdgeInsets.only(
        top: SeniorSpacing.normal,
        right: SeniorSpacing.normal,
        left: SeniorSpacing.normal,
        bottom: SeniorSpacing.xsmall,
      ),
      contentPadding: const EdgeInsets.only(
        left: SeniorSpacing.normal,
        right: SeniorSpacing.normal,
        bottom: SeniorSpacing.normal,
      ),
      content: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          Flexible(
            child: SingleChildScrollView(
              child: Text(
                content,
                style: SeniorTypography.text(
                  color: style?.contentColor ??
                      theme?.modalTheme?.style?.contentColor ??
                      defaultTheme.modalTheme?.style?.contentColor ??
                      SeniorColors.secondaryColor700,
                ),
              ),
            ),
          ),
          const SizedBox(
            height: SeniorSpacing.xsmall,
          ),
          actionButton ?? const SizedBox.shrink(),
          const SizedBox(
            height: SeniorSpacing.xsmall,
          ),
          ghostButton
        ],
      ),
    );
  }
}

==> senior_design_system-2.2.16.tar.gz: lib/components/senior_modal/senior_modal_widget.dart <==
import 'package:flutter/material.dart';

import 'package:provider/provider.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import './senior_modal_style.dart';
import '../../components/senior_button/senior_button.dart';
import '../../repositories/theme_repository.dart';

class SeniorModal extends StatelessWidget {
  /// Displays a modal according to SDS definitions.
  ///
  /// The [content], [ghostButton] and [title] parameters are required.
  const SeniorModal({
    Key? key,
    this.actionButton,
    required this.content,
    required this.ghostButton,
    this.style,
    required this.title,
  }) : super(key: key);

  /// Modal action button. It is recommended to use a button that is not of type [SeniorButtonType.ghost].
  final SeniorButton? actionButton;

  /// The information content that will be displayed in the modal.
  final String content;

  /// Modal action button. It is recommended to use a button of type [SeniorButtonType.ghost].
  final SeniorButton ghostButton;

  /// The component's style definitions.
  ///
  /// Allows you to configure:
  /// [SeniorModalStyle.backgroundColor] the background color of the modal.
  final SeniorModalStyle? style;

  /// The modal title.
  final String title;

  @override
  Widget build(BuildContext context) {
    final theme = Provider.of<ThemeRepository>(context).theme;

    return AlertDialog(
      backgroundColor: style?.backgroundColor ?? theme.modalTheme?.style?.backgroundColor ?? SeniorColors.pureWhite,
      title: Text(
        title,
        style: SeniorTypography.h3(
          color: style?.titleColor ?? theme.modalTheme?.style?.titleColor ?? SeniorColors.neutralColor800,
        ),
      ),
      titlePadding: const EdgeInsets.only(
        top: SeniorSpacing.normal,
        right: SeniorSpacing.normal,
        left: SeniorSpacing.normal,
        bottom: SeniorSpacing.xsmall,
      ),
      contentPadding: const EdgeInsets.only(
        left: SeniorSpacing.normal,
        right: SeniorSpacing.normal,
        bottom: SeniorSpacing.normal,
      ),
      content: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          Flexible(
            child: SingleChildScrollView(
              child: Text(
                content,
                style: SeniorTypography.label(
                  color: style?.contentColor ?? theme.modalTheme?.style?.contentColor ?? SeniorColors.secondaryColor700,
                ),
              ),
            ),
          ),
          const SizedBox(
            height: SeniorSpacing.xsmall,
          ),
          actionButton ?? const SizedBox.shrink(),
          const SizedBox(
            height: SeniorSpacing.xsmall,
          ),
          ghostButton
        ],
      ),
    );
  }
}
